==> jc-1.4.0.tar.gz: soot/jimple/internal/JTrap.h <==
// public class soot.jimple.internal.JTrap

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 29fff555fe64e924 soot_AbstractTrap
// @dep_class 7f53b30689e03f05 soot_jimple_internal_JTrap

// header file dependencies
// @dep_header soot_AbstractTrap

#include "soot/AbstractTrap.h"

#ifndef _JC_soot_jimple_internal_JTrap_H_
#define _JC_soot_jimple_internal_JTrap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_Unit$object;
struct _jc_soot_UnitBox$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JTrap$sub_refs	_jc_soot_jimple_internal_JTrap$sub_refs;
typedef struct _jc_soot_jimple_internal_JTrap$sub_nonrefs	_jc_soot_jimple_internal_JTrap$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JTrap$refs	_jc_soot_jimple_internal_JTrap$refs;
typedef struct _jc_soot_jimple_internal_JTrap$nonrefs	_jc_soot_jimple_internal_JTrap$nonrefs;
typedef struct _jc_soot_jimple_internal_JTrap$object	_jc_soot_jimple_internal_JTrap$object;

typedef const struct _jc_soot_jimple_internal_JTrap$vmethods	_jc_soot_jimple_internal_JTrap$vmethods;
typedef const struct _jc_soot_jimple_internal_JTrap$vtable	_jc_soot_jimple_internal_JTrap$vtable;
typedef const struct _jc_soot_jimple_internal_JTrap$vtype	_jc_soot_jimple_internal_JTrap$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JTrap$method$_init$a95ad0a460493016(_jc_env *, struct _jc_soot_jimple_internal_JTrap$object *, struct _jc_soot_SootClass$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);
extern void _jc_soot_jimple_internal_JTrap$method$_init$e16b29be1a08b813(_jc_env *, struct _jc_soot_jimple_internal_JTrap$object *, struct _jc_soot_SootClass$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JTrap$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JTrap$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JTrap$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_internal_JTrap$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JTrap$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JTrap$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_internal_JTrap$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JTrap$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_internal_JTrap$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JTrap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractTrap$vmethods	soot_AbstractTrap;
	_jc_soot_jimple_internal_JTrap$vmethods	soot_jimple_internal_JTrap;
};

// Vtype
struct _jc_soot_jimple_internal_JTrap$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JTrap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JTrap$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JTrap$refs {
    _jc_soot_jimple_internal_JTrap$sub_refs	soot_jimple_internal_JTrap;
    _jc_soot_AbstractTrap$sub_refs	soot_AbstractTrap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JTrap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JTrap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractTrap$sub_nonrefs	soot_AbstractTrap;
    _jc_soot_jimple_internal_JTrap$sub_nonrefs	soot_jimple_internal_JTrap;
};

// Object instance structure
struct _jc_soot_jimple_internal_JTrap$object {
	_jc_soot_jimple_internal_JTrap$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JTrap$vtype	*vtype;
	_jc_soot_jimple_internal_JTrap$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JTrap$vtype _jc_soot_jimple_internal_JTrap$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JTrap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JTrap$class_object;

#endif	/* _JC_soot_jimple_internal_JTrap_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JTrap.h <==
// public class soot.jimple.internal.JTrap

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 29fff555fe64e924 soot_AbstractTrap
// @dep_class 7f53b30689e03f05 soot_jimple_internal_JTrap

// header file dependencies
// @dep_header soot_AbstractTrap

#include "soot/AbstractTrap.h"

#ifndef _JC_soot_jimple_internal_JTrap_H_
#define _JC_soot_jimple_internal_JTrap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_Unit$object;
struct _jc_soot_UnitBox$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JTrap$sub_refs	_jc_soot_jimple_internal_JTrap$sub_refs;
typedef struct _jc_soot_jimple_internal_JTrap$sub_nonrefs	_jc_soot_jimple_internal_JTrap$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JTrap$refs	_jc_soot_jimple_internal_JTrap$refs;
typedef struct _jc_soot_jimple_internal_JTrap$nonrefs	_jc_soot_jimple_internal_JTrap$nonrefs;
typedef struct _jc_soot_jimple_internal_JTrap$object	_jc_soot_jimple_internal_JTrap$object;

typedef const struct _jc_soot_jimple_internal_JTrap$vmethods	_jc_soot_jimple_internal_JTrap$vmethods;
typedef const struct _jc_soot_jimple_internal_JTrap$vtable	_jc_soot_jimple_internal_JTrap$vtable;
typedef const struct _jc_soot_jimple_internal_JTrap$vtype	_jc_soot_jimple_internal_JTrap$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JTrap$method$_init$a95ad0a460493016(_jc_env *, struct _jc_soot_jimple_internal_JTrap$object *, struct _jc_soot_SootClass$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JTrap$method$_init$e16b29be1a08b813(_jc_env *, struct _jc_soot_jimple_internal_JTrap$object *, struct _jc_soot_SootClass$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JTrap$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JTrap$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JTrap$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_internal_JTrap$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JTrap$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JTrap$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_internal_JTrap$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JTrap$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_internal_JTrap$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JTrap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractTrap$vmethods	soot_AbstractTrap;
	_jc_soot_jimple_internal_JTrap$vmethods	soot_jimple_internal_JTrap;
};

// Vtype
struct _jc_soot_jimple_internal_JTrap$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JTrap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JTrap$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JTrap$refs {
    _jc_soot_jimple_internal_JTrap$sub_refs	soot_jimple_internal_JTrap;
    _jc_soot_AbstractTrap$sub_refs	soot_AbstractTrap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JTrap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JTrap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractTrap$sub_nonrefs	soot_AbstractTrap;
    _jc_soot_jimple_internal_JTrap$sub_nonrefs	soot_jimple_internal_JTrap;
};

// Object instance structure
struct _jc_soot_jimple_internal_JTrap$object {
	_jc_soot_jimple_internal_JTrap$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JTrap$vtype	*vtype;
	_jc_soot_jimple_internal_JTrap$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JTrap$vtype _jc_soot_jimple_internal_JTrap$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JTrap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JTrap$class_object;

#endif	/* _JC_soot_jimple_internal_JTrap_H_ */
